/***************************************************************************

 Author        : Neil Zhao - CAST

 Date          : July 20th, 2009

 File          : AD7478_IO.c

 Hardware      : ADuC7026 and AD7478

 Description   : Use the GPIO to simulate the SPI communication of AD7478
	
***************************************************************************/
#include <ADuC7026.h>
#include "AD7478_IO.h"

#define SET_CS()		GP4DAT = (GP4DAT | 0x00080000)	//P4.3->CS
#define CLR_CS()		GP4DAT = (GP4DAT & 0xFFF7FFFF)

#define	SET_SCL()		GP4DAT = (GP4DAT | 0x00100000)	//P4.4->SCLK
#define	CLR_SCL()		GP4DAT = (GP4DAT & 0xffefffff)

void delay (int length)
{
	while (length >0)
    	length--;
}


//---------------------------------
//ReadFromAD7478();
//---------------------------------
//Function that reads from the AD7478 via the SPI port. 
//--------------------------------------------------------------------------
void ReadFromAD7478(unsigned char *buf)
{
	unsigned	char	i = 0;
	unsigned	char	j = 0;
	unsigned	char	k = 0;
	unsigned	int  	iTemp = 0;
	unsigned	char  	RotateData = 0;
	SET_SCL();
	delay(1);
	CLR_CS();
	for(i=0; i<4; i++)
	{
		SET_SCL();
		delay(1);
		iTemp = GP0DAT;			
		CLR_SCL();
		delay(1);
		
	}
	for(j=0; j<8; j++)
	{
	    
		SET_SCL();
		RotateData <<= 1;		//Rotate data
		delay(1);
		iTemp = GP0DAT;			//Read DIN of AD7478
		CLR_SCL();	
		if(0x00000020 == (iTemp & 0x00000020))
		{
			RotateData |= 1;	
		}
		delay(1);
	}
	for(k=0; k<4; k++)
	{
		SET_SCL();
		delay(1);
		iTemp = GP0DAT;			
		CLR_SCL();
		delay(1);
		
	}
	*buf= RotateData;
	SET_SCL();
	delay(1);
	SET_CS();	 

} 

//---------------------------------
//EnablePowerUp()
//---------------------------------
//Function that makes AD7478 into PowerUp Mode. 
//-------------------------------------------------------------------------
void EnablePowerUp()
{	
	unsigned	char	i = 0;
	
	CLR_CS();
	for(i=0;i<12;i++)
	{
		SET_SCL();
		delay(1);
		CLR_SCL();
		delay(1);
	}
	SET_CS();
	for(i=0;i<4;i++)
	{
		SET_SCL();
		delay(1);
		CLR_SCL();
		delay(1);
	}
	delay(5);
}

//---------------------------------
//EnablePowerDown()
//---------------------------------
//Function that makes AD7478 into PowerDown Mode. 
//--------------------------------------------------------------------------
void EnablePowerDown()
{	
	unsigned	char	i = 0;
	
	CLR_CS();
	for(i=0;i<6;i++)
	{
		SET_SCL();
		delay(1);
		CLR_SCL();
		delay(1);
	}
	SET_CS();
	for(i=0;i<10;i++)
	{
		SET_SCL();
		delay(1);
		CLR_SCL();
		delay(1);
	}
	delay(5);
}


